@@ -3,7 +3,7 @@ package Net::FullAuto::ISets::Amazon::Liferay_is;
 ### OPEN SOURCE LICENSE - GNU AFFERO PUBLIC LICENSE Version 3.0 #######
 #
 #    Net::FullAuto - Powerful Network Process Automation Software
-#    Copyright © 2000-2016  Brian M. Kelly
+#    Copyright © 2000-2015  Brian M. Kelly
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as
@@ -248,7 +248,7 @@ END
    my ($hash,$json,$output,$error)=('','','','');
    my $in_id=$lr_inst->{InstanceId};
    ($hash,$output,$error)=
-       Net::FullAuto::FA_Core::run_aws_cmd("aws ec2 describe-instances ".
+       run_aws_cmd("aws ec2 describe-instances ".
        "--filters Name=instance-id,Values=$in_id");
    if ($error) {
       print $error;
@@ -391,7 +391,7 @@ END
    my ($hash,$json,$output,$error)=('','','','');
    my $in_id=$main::aws->{$server_type}->[$cnt]->[0]->{InstanceId};
    ($hash,$output,$error)=
-       Net::FullAuto::FA_Core::run_aws_cmd("aws ec2 describe-instances ".
+       run_aws_cmd("aws ec2 describe-instances ".
        "--filters Name=instance-id,Values=$in_id");
    if ($error) {
       print $error;
@@ -481,7 +481,7 @@ END
    while (1) {
       my $s="aws s3 mb s3://$lrbn 2>&1";
       my ($hash,$output,$error)=('','','');
-      ($hash,$output,$error)=Net::FullAuto::FA_Core::run_aws_cmd($s);
+      ($hash,$output,$error)=run_aws_cmd($s);
       print "   ".$output;
       if ((-1<index $output,'bucket name is not avail') ||
             ((-1<index $output,'you already own it') &&
@@ -570,74 +570,74 @@ my $standup_liferay=sub {
    my $c='aws ec2 describe-security-groups '.
          "--group-names $n";
    my ($hash,$output,$error)=('','','');
-   ($hash,$output,$error)=Net::FullAuto::FA_Core::run_aws_cmd($c);
+   ($hash,$output,$error)=run_aws_cmd($c);
    Net::FullAuto::FA_Core::handle_error($error) if $error;
    my $cidr=$hash->{SecurityGroups}->[0]->{IpPermissions}
             ->[0]->{IpRanges}->[0]->{CidrIp};
    $c='aws ec2 create-security-group --group-name '.
       'LiferaySecurityGroup --description '.
       '"Liferay.com Security Group" 2>&1';
-   ($hash,$output,$error)=Net::FullAuto::FA_Core::run_aws_cmd($c);
+   ($hash,$output,$error)=run_aws_cmd($c);
    Net::FullAuto::FA_Core::handle_error($error) if $error
       && $error!~/already exists/;
    $c='aws ec2 authorize-security-group-ingress '.
       '--group-name LiferaySecurityGroup --protocol '.
       'tcp --port 22 --cidr '.$cidr." 2>&1";
-   ($hash,$output,$error)=Net::FullAuto::FA_Core::run_aws_cmd($c);
+   ($hash,$output,$error)=run_aws_cmd($c);
    Net::FullAuto::FA_Core::handle_error($error) if $error
       && $error!~/already exists/;
    $c='aws ec2 authorize-security-group-ingress '.
       '--group-name LiferaySecurityGroup --protocol '.
       'tcp --port 8080 --cidr '.$cidr." 2>&1";
-   ($hash,$output,$error)=Net::FullAuto::FA_Core::run_aws_cmd($c);
+   ($hash,$output,$error)=run_aws_cmd($c);
    Net::FullAuto::FA_Core::handle_error($error) if $error
       && $error!~/already exists/;
    $c='aws ec2 authorize-security-group-ingress '.
       '--group-name LiferaySecurityGroup --protocol '.
       'tcp --port 8081 --cidr '.$cidr." 2>&1";
-   ($hash,$output,$error)=Net::FullAuto::FA_Core::run_aws_cmd($c);
+   ($hash,$output,$error)=run_aws_cmd($c);
    Net::FullAuto::FA_Core::handle_error($error) if $error
       && $error!~/already exists/;
    $c='aws ec2 create-security-group --group-name '.
       'ApacheSecurityGroup --description '.
       '"Apache.org Security Group" 2>&1';
-   ($hash,$output,$error)=Net::FullAuto::FA_Core::run_aws_cmd($c);
+   ($hash,$output,$error)=run_aws_cmd($c);
    Net::FullAuto::FA_Core::handle_error($error) if $error
       && $error!~/already exists/;
    $c='aws ec2 authorize-security-group-ingress '.
       '--group-name ApacheSecurityGroup --protocol '.
       'tcp --port 22 --cidr '.$cidr." 2>&1";
-   ($hash,$output,$error)=Net::FullAuto::FA_Core::run_aws_cmd($c);
+   ($hash,$output,$error)=run_aws_cmd($c);
    Net::FullAuto::FA_Core::handle_error($error) if $error
       && $error!~/already exists/;
    $c='aws ec2 authorize-security-group-ingress '.
       '--group-name ApacheSecurityGroup --protocol '.
       'tcp --port 80 --cidr '.$cidr." 2>&1";
-   ($hash,$output,$error)=Net::FullAuto::FA_Core::run_aws_cmd($c);
+   ($hash,$output,$error)=run_aws_cmd($c);
    Net::FullAuto::FA_Core::handle_error($error) if $error
       && $error!~/already exists/;
    $c='aws ec2 authorize-security-group-ingress '.
       '--group-name ApacheSecurityGroup --protocol '.
       'tcp --port 443 --cidr '.$cidr." 2>&1";
-   ($hash,$output,$error)=Net::FullAuto::FA_Core::run_aws_cmd($c);
+   ($hash,$output,$error)=run_aws_cmd($c);
    Net::FullAuto::FA_Core::handle_error($error) if $error
       && $error!~/already exists/;
    $c='aws ec2 create-security-group --group-name '.
       'MySQLSecurityGroup --description '.
       '"MySQL Security Group" 2>&1';
-   ($hash,$output,$error)=Net::FullAuto::FA_Core::run_aws_cmd($c);
+   ($hash,$output,$error)=run_aws_cmd($c);
    Net::FullAuto::FA_Core::handle_error($error) if $error
       && $error!~/already exists/;
    $c='aws ec2 authorize-security-group-ingress '.
       '--group-name MySQLSecurityGroup --protocol '.
       'tcp --port 22 --cidr '.$cidr." 2>&1";
-   ($hash,$output,$error)=Net::FullAuto::FA_Core::run_aws_cmd($c);
+   ($hash,$output,$error)=run_aws_cmd($c);
    Net::FullAuto::FA_Core::handle_error($error) if $error
       && $error!~/already exists/;
    $c='aws ec2 authorize-security-group-ingress '.
       '--group-name MySQLSecurityGroup --protocol '.
       'tcp --port 3306 --cidr '.$cidr." 2>&1";
-   ($hash,$output,$error)=Net::FullAuto::FA_Core::run_aws_cmd($c);
+   ($hash,$output,$error)=run_aws_cmd($c);
    Net::FullAuto::FA_Core::handle_error($error) if $error
       && $error!~/already exists/;
    my $cnt=0;
@@ -702,7 +702,7 @@ my $standup_liferay=sub {
           |_| \_|\___|\__|     |_|   \__,_|_|_/_/   \_\__,_|\__\___/ ©
 
 
-   Copyright © 2000-2016  Brian M. Kelly  Brian.Kelly@FullAuto.com
+   Copyright © 2000-2015  Brian M. Kelly  Brian.Kelly@FullAuto.com
 
 END
    eval {
